<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr@latin">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="95"/>
        <source>Show/hide main menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="26"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="50"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="67"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="77"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="90"/>
        <source>Auto-select after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="100"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="125"/>
        <source>Menu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="131"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="147"/>
        <source>Keyboard Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="166"/>
        <source>Click the button to record shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="176"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="182"/>
        <source>Clear search upon showing menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="192"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="208"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="718"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
